--
-- Current Database: `opmon4`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `opmon4` /*!40100 DEFAULT CHARACTER SET latin1 */;
ALTER DATABASE opmon4 DEFAULT CHARSET = utf8;
USE `opmon4`;

-- Store persistent cache
CREATE TABLE cache (
		cache_key varchar(64),
		cache_data 		longblob,
		date_updated datetime,
		PRIMARY KEY (cache_key)
) DEFAULT CHARSET=utf8;


-- store comments for hosts
CREATE TABLE host_comment (
	host_id int(11) unsigned,
	entry_time datetime,
	contact_id int(11) unsigned,
	comment_data text,
	persistent int(10) NOT NULL default '0',
	source int(10) NOT NULL default '0',
	entry_type  int(10) NOT NULL default '0',
	expires int(10) NOT NULL default '0',
	expire_time datetime,
	comment_id int(10) NOT NULL default '0',
	KEY host_comment_1_idx (host_id,`entry_time`),
	KEY host_comment_2_idx (contact_id,host_id,`entry_time`)
) DEFAULT CHARSET=utf8;

ALTER TABLE host_comment DROP PRIMARY KEY;


/* store comments for hosts */
CREATE TABLE service_comment (
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	entry_time datetime,
	contact_id int(11) unsigned,
	comment_data text,
	persistent int(10) NOT NULL default '0',
	source int(10) NOT NULL default '0',
	entry_type  int(10) NOT NULL default '0',
	expires int(10) NOT NULL default '0',
	expire_time datetime,
	comment_id int(10) NOT NULL default '0',
	KEY service_comment_1_idx (host_id,service_id,`entry_time`),
	KEY service_comment_2_idx (contact_id,host_id,service_id,`entry_time`)
) DEFAULT CHARSET=utf8;

ALTER TABLE service_comment DROP PRIMARY KEY;

/* Stores schedule downtimes for hosts */
CREATE TABLE host_downtime (
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	entry_time datetime,
	contact_id int(11) unsigned,
	comment_data text,
	start_time datetime NOT NULL,
	end_time datetime NOT NULL,
	fixed int(10) NOT NULL default '0',
	duration int(10) NOT NULL default '0',
	triggered_by int(10) NOT NULL default '0',
	downtime_id int(10) NOT NULL default '0',
	attr int(10) default '1',
	KEY host_downtime_1_idx (entry_time, host_id, downtime_id),
	KEY host_downtime_2_idx (start_time, end_time, host_id),
	KEY host_downtime_3_idx (end_time, start_time, host_id)
) DEFAULT CHARSET=utf8;
ALTER IGNORE TABLE host_downtime DROP PRIMARY KEY;
ALTER IGNORE TABLE host_downtime ADD PRIMARY KEY(host_id,entry_time);
DROP INDEX host_downtime_4_idx ON host_downtime;
UPDATE host_downtime SET type=1104 WHERE end_time < now() AND type <> 1105;


/* Store schedule downtimes for host and services */
CREATE TABLE service_downtime (
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	service_id int(11) unsigned,
	entry_time datetime,
	contact_id int(11) unsigned,
	comment_data text,
	start_time datetime NOT NULL,
	end_time datetime NOT NULL,
	fixed int(10) NOT NULL default '0',
	duration int(10) NOT NULL default '0',
	triggered_by int(10) NOT NULL default '0',
	downtime_id int(10) NOT NULL default '0',
	attr int(10) default '1',
	KEY service_downtime_1_idx (entry_time, host_id, downtime_id),
	KEY service_downtime_2_idx (start_time, end_time, host_id),
	KEY service_downtime_3_idx (end_time, start_time, host_id)
) DEFAULT CHARSET=utf8;
ALTER IGNORE TABLE service_downtime DROP PRIMARY KEY;
ALTER IGNORE TABLE service_downtime ADD PRIMARY KEY(host_id,service_id,entry_time);
DROP INDEX service_downtime_4_idx ON service_downtime;
UPDATE service_downtime SET type=1104 WHERE end_time < now() AND type <> 1105;


CREATE TABLE host_notification (
	entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	contact_id int(11) unsigned,
	command_id int(11) unsigned,
	command_args text,
	reason_type int(10) NOT NULL default '0',
	state int(10) NOT NULL default '0',
	output text,
	ack_author_id int(11) unsigned,
	ack_data text,
	escalated int(10) NOT NULL default '0',
	start_time datetime,
	end_time datetime,
	PRIMARY KEY (entry_time, host_id, contact_id, command_id, reason_type, state),
	KEY host_notification_1_idx (host_id, contact_id, entry_time),
	KEY host_notification_2_idx (state, contact_id, entry_time),
	KEY host_notification_3_idx (reason_type, state, contact_id, entry_time),
	KEY host_notification_4_idx (command_id, contact_id, host_id, entry_time),
	KEY host_notification_5_idx (contact_id, entry_time, host_id)
) DEFAULT CHARSET=utf8;

CREATE TABLE service_notification (
	`entry_time` datetime NOT NULL default '0000-00-00 00:00:00',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	contact_id int(11) unsigned,
	command_id int(11) unsigned,
	command_args text,
	reason_type int(10) NOT NULL default '0',
	state int(10) NOT NULL default '0',
	output text,
	ack_author_id int(11) unsigned,
	ack_data text,
	escalated int(10) NOT NULL default '0',
	start_time datetime,
	end_time datetime,
	PRIMARY KEY (`entry_time`, host_id, contact_id, command_id, reason_type, state),
	KEY service_notification_1_idx (host_id, service_id, contact_id, `entry_time`),
	KEY service_notification_2_idx (state, contact_id, `entry_time`),
	KEY service_notification_3_idx (reason_type, state, contact_id, `entry_time`),
	KEY service_notification_4_idx (command_id, contact_id, host_id, `entry_time`),
	KEY service_notification_5_idx (contact_id, `entry_time`, host_id, service_id)
) DEFAULT CHARSET=utf8;

CREATE TABLE host_flapping (
	entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	comment_id int(10) NOT NULL default '0',
	percent_change float,
	high_threshold float,
	low_threshold float,
	PRIMARY KEY (`entry_time`, host_id, type),
	KEY host_flapping_1_idx (host_id, `entry_time`),
	KEY host_flapping_2_idx (comment_id)
) DEFAULT CHARSET=utf8;

CREATE TABLE service_flapping (
	`entry_time` datetime NOT NULL default '0000-00-00 00:00:00',
	type int(10) NOT NULL default '0',
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	comment_id int(10) NOT NULL default '0',
	percent_change float,
	high_threshold float,
	low_threshold float,
	PRIMARY KEY (`entry_time`, host_id, service_id, type),
	KEY service_flapping_1_idx (host_id, service_id, `entry_time`),
	KEY service_flapping_2_idx (comment_id)
) DEFAULT CHARSET=utf8;

CREATE TABLE host_external_command (
  host_id int(11) unsigned,
  entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	command_type varchar(256) DEFAULT '',
	contact_id int(11) unsigned,
	command_args text,
	PRIMARY KEY (entry_time, host_id, command_type(128),contact_id),
	KEY external_command_host_1_idx (command_type,contact_id,entry_time),
	KEY external_command_host_2_idx (contact_id,command_type,entry_time)
) DEFAULT CHARSET=utf8;

CREATE TABLE service_external_command (
  host_id int(11) unsigned,
  service_id int(11) unsigned,
  entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	command_type varchar(256) DEFAULT '',
	contact_id int(11) unsigned,
	command_args text,
	PRIMARY KEY (entry_time, host_id, service_id, command_type(128),contact_id),
	KEY external_command_service_1_idx (command_type,contact_id ,entry_time),
	KEY external_command_service_2_idx (contact_id,command_type,entry_time)
) DEFAULT CHARSET=utf8;

CREATE TABLE hostgroup_external_command (
  hostgroup_id int(11) unsigned,
  entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	command_type varchar(256) DEFAULT '',
	contact_id int(11) unsigned,
	command_args text,
	PRIMARY KEY (entry_time, hostgroup_id, command_type(128),contact_id),
	KEY external_command_hostgroup_1_idx (command_type,contact_id,entry_time),
	KEY external_command_hostgroup_2_idx (contact_id,command_type,entry_time)
) DEFAULT CHARSET=utf8;


CREATE TABLE servicegroup_external_command (
  servicegroup_id int(11) unsigned,
  entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	command_type varchar(256) DEFAULT '',
	contact_id int(11) unsigned,
	command_args text,
	PRIMARY KEY (entry_time, servicegroup_id, command_type(128),contact_id),
	KEY external_command_servicegroup_1_idx (command_type,contact_id,entry_time),
	KEY external_command_servicegroup_2_idx (contact_id,command_type,entry_time)
) DEFAULT CHARSET=utf8;


CREATE TABLE host_status (
	host_id int(11) unsigned,
	host_name varchar(128),
	problem_has_been_acknowledged int(10) NOT NULL default '0',
	acknowledgement_type int(10) NOT NULL default '0',
	check_type int(10) NOT NULL default '0',
	current_state int(10) NOT NULL default '0',
	last_state int(10) NOT NULL default '0',
	last_hard_state int(10) NOT NULL default '0',
	plugin_output varchar(1024),
	long_plugin_output text,
	perf_data varchar(1024),
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	latency float,
	execution_time float,
	is_executing int(10) NOT NULL default '0',
	check_options int(10) NOT NULL default '0',
	notifications_enabled int(10) NOT NULL default '0',
	last_host_notification datetime,
	next_host_notification datetime,
	next_check datetime,
	should_be_scheduled int(10) NOT NULL default '0',
	last_check datetime,
	last_state_change datetime,
	last_hard_state_change datetime,
	last_time_up datetime,
	last_time_down datetime,
	last_time_unreachable datetime,
	has_been_checked int(10) NOT NULL default '0',
	is_being_freshened int(10) NOT NULL default '0',
	notified_on_down int(10) NOT NULL default '0',
	notified_on_unreachable int(10) NOT NULL default '0',
	current_notification_number int(10) NOT NULL default '0',
	no_more_notifications int(10) NOT NULL default '0',
	current_notification_id int(10) NOT NULL default '0',
	check_flapping_recovery_notification int(10) NOT NULL default '0',
	scheduled_downtime_depth int(10) NOT NULL default '0',
	pending_flex_downtime int(10) NOT NULL default '0',
	is_flapping int(10) NOT NULL default '0',
	flapping_comment_id int(10) NOT NULL default '0',
	percent_state_change float,
	total_services int(10) NOT NULL default '0',
	total_service_check_interval int(10) NOT NULL default '0',
	modified_attributes int(10) NOT NULL default '0',
	check_command varchar(1024),
	check_period varchar(128),
	notification_period varchar(128),
	check_interval float,
	retry_interval float,
	event_handler varchar(1024),
	current_problem_id int(10) NOT NULL default '0',
	last_problem_id int(10) NOT NULL default '0',
	max_attempts int(10) NOT NULL default '1',
	current_event_id int(10) NOT NULL default '0',
	last_event_id int(10) NOT NULL default '0',
	active_checks_enabled int(10) NOT NULL default '0',
	passive_checks_enabled int(10) NOT NULL default '0',
	event_handler_enabled int(10) NOT NULL default '0',
	flap_detection_enabled int(10) NOT NULL default '0',
	failure_prediction_enabled int(10) NOT NULL default '0',
	process_performance_data int(10) NOT NULL default '0',
	obsess_over_host int(10) NOT NULL default '0',
	notes_url varchar(1024),
	action_url varchar(1024),
	icon_image varchar(256),
	PRIMARY KEY (host_id),
	KEY host_status_1_idx (next_check, host_id),
	KEY host_status_2_idx (last_check, host_id),
	KEY host_status_3_idx (last_state_change, host_id),
	KEY host_status_4_idx (last_hard_state_change, host_id),
	KEY host_status_5_idx (last_time_up, host_id),
	KEY host_status_6_idx (last_time_down, host_id),
	KEY host_status_7_idx (last_time_unreachable, host_id),
	KEY host_status_8_idx (latency, host_id),
	KEY host_status_9_idx (execution_time, host_id),
	KEY host_status_10_idx (host_name)
) DEFAULT CHARSET=utf8;

ALTER TABLE host_status ADD COLUMN `export_date` datetime;
CREATE INDEX host_status_11_idx on host_status (export_date);
UPDATE host_status set export_date=NOW();

/* Removing stupid unsued columns */
ALTER TABLE host_status DROP COLUMN is_executing;
ALTER TABLE host_status DROP COLUMN check_options;
ALTER TABLE host_status DROP COLUMN last_host_notification;
ALTER TABLE host_status DROP COLUMN next_host_notification;
ALTER TABLE host_status DROP COLUMN should_be_scheduled;
ALTER TABLE host_status DROP COLUMN last_hard_state_change;
ALTER TABLE host_status DROP COLUMN last_time_up;
ALTER TABLE host_status DROP COLUMN last_time_down;
ALTER TABLE host_status DROP COLUMN last_time_unreachable;
ALTER TABLE host_status DROP COLUMN has_been_checked;
ALTER TABLE host_status DROP COLUMN is_being_freshened;
ALTER TABLE host_status DROP COLUMN notified_on_down;
ALTER TABLE host_status DROP COLUMN notified_on_unreachable;
ALTER TABLE host_status DROP COLUMN current_notification_number;
ALTER TABLE host_status DROP COLUMN no_more_notifications;
ALTER TABLE host_status DROP COLUMN current_notification_id;
ALTER TABLE host_status DROP COLUMN check_flapping_recovery_notification;
ALTER TABLE host_status DROP COLUMN pending_flex_downtime;
ALTER TABLE host_status DROP COLUMN flapping_comment_id;
ALTER TABLE host_status DROP COLUMN percent_state_change;
ALTER TABLE host_status DROP COLUMN total_service_check_interval;
ALTER TABLE host_status DROP COLUMN current_problem_id;
ALTER TABLE host_status DROP COLUMN last_problem_id;
ALTER TABLE host_status DROP COLUMN current_event_id;
ALTER TABLE host_status DROP COLUMN last_event_id;
ALTER TABLE host_status DROP COLUMN failure_prediction_enabled;

CREATE TABLE service_status (
	host_id int(11) unsigned,
	`service_id` int(11) unsigned,
	host_name varchar(128),
	service_description varchar(128),
	problem_has_been_acknowledged int(10) NOT NULL default '0',
	acknowledgement_type int(10) NOT NULL default '0',
	host_problem_at_last_check int(10) NOT NULL default '0',
	check_type int(10) NOT NULL default '0',
	current_state int(10) NOT NULL default '0',
	last_state int(10) NOT NULL default '0',
	last_hard_state int(10) NOT NULL default '0',
	plugin_output varchar(1024),
	long_plugin_output text,
	perf_data varchar(1024),
	state_type int(10) NOT NULL default '0',
	next_check datetime,
	should_be_scheduled int(10) NOT NULL default '0',
	last_check datetime,
	current_attempt int(10) NOT NULL default '0',
	current_event_id int(10) NOT NULL default '0',
	last_event_id int(10) NOT NULL default '0',
	current_problem_id int(10) NOT NULL default '0',
	last_problem_id int(10) NOT NULL default '0',
	last_notification datetime,
	next_notification datetime,
	no_more_notifications int(10) NOT NULL default '0',
	check_flapping_recovery_notification int(10) NOT NULL default '0',
	last_state_change datetime,
	last_hard_state_change datetime,
	last_time_ok datetime,
	last_time_warning datetime,
	last_time_unknown datetime,
	last_time_critical datetime,
	has_been_checked int(10) NOT NULL default '0',
	is_being_freshened int(10) NOT NULL default '0',
	notified_on_unknown int(10) NOT NULL default '0',
	notified_on_warning int(10) NOT NULL default '0',
	notified_on_critical int(10) NOT NULL default '0',
	current_notification_number int(10) NOT NULL default '0',
	current_notification_id int(10) NOT NULL default '0',
	latency float,
	execution_time float,
	is_executing int(10) NOT NULL default '0',
	check_options int(10) NOT NULL default '0',
	scheduled_downtime_depth int(10) NOT NULL default '0',
	pending_flex_downtime int(10) NOT NULL default '0',
	is_flapping int(10) NOT NULL default '0',
	flapping_comment_id int(10) NOT NULL default '0',
	percent_state_change float,
	modified_attributes int(10) NOT NULL default '0',
	check_command varchar(128),
	check_period varchar(128),
	notification_period varchar(128),
	check_interval float,
	retry_interval float,
	event_handler varchar(1024),
	max_attempts int(10) NOT NULL default '0',
	notifications_enabled int(10) NOT NULL default '0',
	active_checks_enabled int(10) NOT NULL default '0',
	passive_checks_enabled int(10) NOT NULL default '0',
	event_handler_enabled int(10) NOT NULL default '0',
	flap_detection_enabled int(10) NOT NULL default '0',
	failure_prediction_enabled int(10) NOT NULL default '0',
	process_performance_data int(10) NOT NULL default '0',
	obsess_over_service int(10) NOT NULL default '0',
	notes_url varchar(1024),
	action_url varchar(1024),
	icon_image varchar(256),
	host_icon_image varchar(256),
	PRIMARY KEY (host_id, service_id),
	KEY service_status_1_idx (next_check, host_id, service_id),
	KEY service_status_2_idx (last_check, host_id, service_id),
	KEY service_status_3_idx (last_state_change, host_id, service_id),
	KEY service_status_4_idx (last_hard_state_change, host_id, service_id),
	KEY service_status_5_idx (last_time_ok, host_id, service_id),
	KEY service_status_6_idx (last_time_warning, host_id, service_id),
	KEY service_status_7_idx (last_time_unknown, host_id, service_id),
	KEY service_status_8_idx (last_time_critical, host_id, service_id),
	KEY service_status_9_idx (latency, host_id, service_id),
	KEY service_status_10_idx (execution_time, host_id, service_id),
	KEY service_status_11_idx (host_name,service_description)
) DEFAULT CHARSET=utf8;

ALTER TABLE service_status ADD COLUMN `export_date` datetime;
CREATE INDEX service_status_12_idx on service_status (export_date);
CREATE INDEX service_status_13_idx on opmon4.service_status (service_id);
UPDATE service_status set export_date=NOW();
ALTER TABLE service_status MODIFY long_plugin_output longtext;

/* Removing stupid unsued columns */
ALTER TABLE service_status DROP COLUMN host_problem_at_last_check;
ALTER TABLE service_status DROP COLUMN current_event_id;
ALTER TABLE service_status DROP COLUMN last_event_id;
ALTER TABLE service_status DROP COLUMN current_problem_id;
ALTER TABLE service_status DROP COLUMN last_problem_id;
ALTER TABLE service_status DROP COLUMN last_hard_state_change;
ALTER TABLE service_status DROP COLUMN last_time_ok;
ALTER TABLE service_status DROP COLUMN last_time_warning;
ALTER TABLE service_status DROP COLUMN last_time_unknown;
ALTER TABLE service_status DROP COLUMN last_time_critical;
ALTER TABLE service_status DROP COLUMN has_been_checked;
ALTER TABLE service_status DROP COLUMN is_being_freshened;
ALTER TABLE service_status DROP COLUMN notified_on_unknown;
ALTER TABLE service_status DROP COLUMN notified_on_warning;
ALTER TABLE service_status DROP COLUMN notified_on_critical;
ALTER TABLE service_status DROP COLUMN current_notification_number;
ALTER TABLE service_status DROP COLUMN current_notification_id;
ALTER TABLE service_status DROP COLUMN is_executing;
ALTER TABLE service_status DROP COLUMN check_options;
ALTER TABLE service_status DROP COLUMN pending_flex_downtime;
ALTER TABLE service_status DROP COLUMN flapping_comment_id;
ALTER TABLE service_status DROP COLUMN failure_prediction_enabled;
ALTER TABLE service_status DROP COLUMN process_performance_data;
ALTER TABLE service_status DROP COLUMN should_be_scheduled;
ALTER TABLE service_status DROP COLUMN no_more_notifications;
ALTER TABLE service_status DROP COLUMN check_flapping_recovery_notification;
ALTER TABLE service_status DROP COLUMN percent_state_change;


CREATE TABLE `opmon_cmd` (
  id int(10) NOT NULL auto_increment,
  entry_time datetime,
  cmd varchar(255),
  PRIMARY KEY  (id)
) DEFAULT CHARSET=utf8;
ALTER TABLE opmon4.opmon_cmd MODIFY COLUMN cmd varchar(1024);
ALTER TABLE opmon4.opmon_cmd MODIFY COLUMN id bigint NOT NULL auto_increment;

--- Table is deprecated - livestatus instead
DROP TABLE IF EXISTS `event_log`;

CREATE TABLE host_state_change (
	entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	current_state int(10) NOT NULL default '0',
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	plugin_output text default NULL,
	PRIMARY KEY (entry_time, current_state, state_type, current_attempt)
) DEFAULT CHARSET=utf8;

--- Solves bug that the initial table for host opmon was not created on install
CREATE TABLE host_state_change_1 like host_state_change;

CREATE TABLE service_state_change (
	entry_time datetime NOT NULL default '0000-00-00 00:00:00',
	service_id int(11) unsigned,
	current_state int(10) NOT NULL default '0',
	state_type int(10) NOT NULL default '0',
	current_attempt int(10) NOT NULL default '0',
	plugin_output text default NULL,
	PRIMARY KEY (entry_time, service_id, current_state, state_type, current_attempt),
	KEY service_state_change_1_idx (service_id, entry_time)
) DEFAULT CHARSET=utf8;

--- Solves bug that the initial table for host opmon was not created on install
CREATE TABLE service_state_change_1 LIKE service_state_change;


CREATE TABLE program_status (
	entry_time datetime,
	program_state int(11),
	version varchar(64),
	nagios_pid int(11),
	daemon_mode int(11),
	program_start datetime,
	enable_notifications int(11),
	active_service_checks_enabled int(11),
	passive_service_checks_enabled int(11),
	active_host_checks_enabled int(11),
	passive_host_checks_enabled int(11),
	enable_event_handlers int(11),
	obsess_over_services int(11),
	obsess_over_hosts int(11),
	check_service_freshness int(11),
	check_host_freshness int(11),
	enable_flap_detection int(11),
	enable_failure_prediction int(11),
	process_performance_data int(11),
	global_host_event_handler varchar(128),
	global_service_event_handler varchar(128)
) DEFAULT CHARSET=utf8;

ALTER TABLE program_status ADD COLUMN `objects_loaded` int(1) DEFAULT 0;
ALTER TABLE program_status ADD COLUMN `opmon_version` varchar(64);
ALTER TABLE program_status MODIFY COLUMN `opmon_version` varchar(64);
ALTER TABLE program_status ADD COLUMN `id` int(2);
ALTER TABLE program_status ADD CONSTRAINT PRIMARY KEY (id);

--
-- ptables - drop them all, no longer needed
--
DROP TABLE IF EXISTS host_contacts;
DROP TABLE IF EXISTS hostgroup_membership;
DROP TABLE IF EXISTS service_contacts;
DROP TABLE IF EXISTS servicegroup_membership;

---
--- notification center tables
---
CREATE TABLE IF NOT EXISTS opmon4.notification_message (
  notification_id INT(11) NOT NULL AUTO_INCREMENT,
  type INT(11) NOT NULL,
  title VARCHAR(255) NULL DEFAULT NULL,
  text VARCHAR(255) NULL DEFAULT NULL,
  entry_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (notification_id)
) DEFAULT CHARACTER SET = utf8;

ALTER TABLE notification_message ADD COLUMN `external_id` VARCHAR(255) DEFAULT NULL;
ALTER TABLE notification_message ADD COLUMN `lang` VARCHAR(15) NOT NULL;
ALTER TABLE notification_message ADD COLUMN `anchor` VARCHAR(255) DEFAULT NULL;
DROP INDEX notification ON notification_message;
CREATE INDEX type_external_id_idx ON notification_message (`external_id`, `type`);
CREATE INDEX lang_entry_time_idx ON notification_message (`lang`, `entry_time`);
ALTER TABLE notification_message CONVERT TO CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS opmon4.notification_checker (
  contact_id INT(11) NOT NULL,
  notification_id INT(11) NOT NULL,
  entry_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (notification_id, contact_id)
) DEFAULT CHARACTER SET = utf8;

CREATE TABLE IF NOT EXISTS opmon4.version_checker (
  last_check DATETIME NOT NULL,
  current_version VARCHAR(15) NOT NULL
) DEFAULT CHARACTER SET = utf8;
ALTER TABLE opmon4.version_checker ADD UNIQUE KEY `current_version` (`current_version`);
DELETE FROM opmon4.version_checker;

CREATE TABLE `opmon4`.`capacity_prediction` (
    `metric_id` int(11) NOT NULL,
    `host_id` int(11) NOT NULL,
    `service_id` int(11) NOT NULL,
    `data_graph` longblob DEFAULT NULL,
    `unit` varchar(25) DEFAULT NULL,
    `burst_datetime` datetime NOT NULL,
    `burst_value` float NOT NULL,
    `max_value` float NOT NULL,
    `min_value` float DEFAULT 0,
    `last_check` datetime NOT NULL,
    PRIMARY KEY (`host_id`,`service_id`,`metric_id`),
    KEY `metric_id` (`metric_id`),
    KEY `burst_datetime_key` (`burst_datetime`),
    KEY `last_check_key` (`last_check`)
) ENGINE=TokuDB DEFAULT CHARSET=utf8;

--
-- Performance database
--
CREATE DATABASE /*!32312 IF NOT EXISTS*/ `opperf` /*!40100 DEFAULT CHARACTER SET latin1 */;
ALTER DATABASE opperf DEFAULT CHARSET = utf8;
USE opperf;

CREATE TABLE `service_perf` (
  `entry_time` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `service_id` int(11) unsigned NOT NULL DEFAULT '0',
  `metric_id` int(11) unsigned NOT NULL DEFAULT '0',
  `perf_value` double(13,3) DEFAULT NULL,
  `warning` double(13,3) DEFAULT NULL,
  `critical` double(13,3) DEFAULT NULL,
  `baseline` double(13,3) DEFAULT NULL,
  `lower_limit` double(13,3) DEFAULT NULL,
  `upper_limit` double(13,3) DEFAULT NULL,
  `reserved0` double(13,3) DEFAULT NULL,
  `reserved1` double(13,3) DEFAULT NULL,
  `reserved2` double(13,3) DEFAULT NULL,
  PRIMARY KEY (`service_id`,`metric_id`,`entry_time`)
) DEFAULT CHARSET=utf8;
